@@ -3,7 +3,7 @@
       paste0(
         '\n ========================================================================',
         '\n If you have any question about this package and corresponding paper use ',
-		    '\n      hamedhaseli@gmail.com  or visit www.hamedhaseli.webs.com           ',
+		    '\n      hamedhaseli@gmail.com                                              ',
 		    '\n ========================================================================'
          ),
       domain = NULL,  appendLF = TRUE )
